@@ -13,10 +13,9 @@ from las.credentials import MissingCredentials, read_from_file
 
 from .util import NotProvided
 from .parser import (
-    create_assets_parser, create_batches_parser,
-    create_documents_parser, create_logs_parser,
-    create_models_parser, create_predictions_parser,
-    create_secrets_parser, create_transitions_parser,
+    create_app_clients_parser, create_assets_parser, create_batches_parser,
+    create_documents_parser, create_logs_parser, create_models_parser,
+    create_predictions_parser, create_secrets_parser, create_transitions_parser,
     create_users_parser, create_workflows_parser,
 )
 
@@ -27,6 +26,7 @@ def create_parser():
     parser.add_argument('--verbose', '-v', action='count', default=0)
     subparsers = parser.add_subparsers()
 
+    create_app_clients_parser(subparsers)
     create_assets_parser(subparsers)
     create_batches_parser(subparsers)
     create_documents_parser(subparsers)
