@@ -23,6 +23,10 @@ def update_secret(las_client: Client, secret_id, data, **optional_args):
     return las_client.update_secret(secret_id, data=secret_data, **optional_args)
 
 
+def delete_secret(las_client: Client, secret_id):
+    return las_client.delete_secret(secret_id)
+
+
 def create_secrets_parser(subparsers):
     parser = subparsers.add_parser('secrets')
     subparsers = parser.add_subparsers()
@@ -40,9 +44,13 @@ def create_secrets_parser(subparsers):
 
     update_secret_parser = subparsers.add_parser('update')
     update_secret_parser.add_argument('secret_id')
-    update_secret_parser.add_argument('--data', metavar='KEY=VALUE', nargs='+')
+    update_secret_parser.add_argument('--data', metavar='KEY=VALUE', nargs='+', default=[])
     update_secret_parser.add_argument('--name', type=nullable, default=NotProvided)
     update_secret_parser.add_argument('--description', type=nullable, default=NotProvided)
     update_secret_parser.set_defaults(cmd=update_secret)
 
+    delete_secret_parser = subparsers.add_parser('delete')
+    delete_secret_parser.add_argument('secret_id')
+    delete_secret_parser.set_defaults(cmd=delete_secret)
+
     return parser
